==> qtjambi-quick-debuginfo-macos-6.5.4.jar: sources/QtJambiQuick/QSGClipNode_shell.cpp <==
#include "QSGClipNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGClipNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGClipNode")
    QSGClipNode *_ptr = reinterpret_cast<QSGClipNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGClipNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGClipNode_shell) ); }

jmethodID QSGClipNode_shell::__shell_javaMethod(int pos) const { return QSGClipNode_shell::__shell()->javaMethod(typeid(QSGClipNode), pos); }

// emitting (writeShellConstructor)
QSGClipNode_shell::QSGClipNode_shell()
    : QSGClipNode()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGClipNode::QSGClipNode_shell()", QSGClipNode_shell::__shell())
    QSGClipNode_shell::__shell()->constructed(typeid(QSGClipNode));
}

// emitting (writeShellDestructor)
QSGClipNode_shell::~QSGClipNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGClipNode::~QSGClipNode()", QSGClipNode_shell::__shell())
    QSGClipNode_shell::__shell()->destructed(typeid(QSGClipNode));
}

void QSGClipNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGClipNode_shell*>(ptr)->QSGClipNode_shell::__shell()->tryDeleteShell(typeid(QSGClipNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGClipNode_shell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSGClipNode::", QSGClipNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGClipNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGClipNode_shell::__shell()->warnForMethod("QSGClipNode::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGClipNode::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGNode::isSubtreeBlocked();
        }
    }else{
        return QSGNode::isSubtreeBlocked();
    }
}

void QSGClipNode_shell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSGClipNode::", QSGClipNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGClipNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QSGClipNode_shell::__shell()->warnForMethod("QSGClipNode::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGClipNode::");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QSGClipNode()
void __qt_construct_QSGClipNode_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGClipNode()")
    Q_UNUSED(__java_arguments)
    QSGClipNode *__qt_this = new(__qtjambi_ptr) QSGClipNode_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QSGClipNode_shell
void __qt_destruct_QSGClipNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGClipNode")
    reinterpret_cast<QSGClipNode_shell*>(ptr)->~QSGClipNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGClipNode::QSGClipNode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_initialize_1native__Lio_qt_quick_QSGClipNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGClipNode::QSGClipNode()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGClipNode_0, sizeof(QSGClipNode_shell), typeid(QSGClipNode), true, &deleter_QSGClipNode, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGClipNode::clipRect()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_clipRect_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGClipNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGClipNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGClipNode::clipRect()const", __qt_this)
        QRectF __qt_return_value = __qt_this->clipRect();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGClipNode::isRectangular()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_isRectangular_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QSGClipNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGClipNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGClipNode::isRectangular()const", __qt_this)
        __java_return_value = __qt_this->isRectangular();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGClipNode::setClipRect(QRectF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_setClipRect_1native_1cref_1QRectF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGClipNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGClipNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGClipNode::setClipRect(QRectF)", __qt_this)
        const QRectF& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QRectF>(arg__1);
        __qt_this->setClipRect(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGClipNode::setIsRectangular(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_setIsRectangular_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean rectHint0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGClipNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGClipNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGClipNode::setIsRectangular(bool)", __qt_this)
        __qt_this->setIsRectangular(static_cast<bool>(rectHint0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSGClipNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGClipNode>("QSGClipNode", "io/qt/quick/QSGClipNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, &__qt_destruct_QSGClipNode, {
        ConstructorInfo(&__qt_construct_QSGClipNode_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGClipNode);
    registerSizeOfShell(typeId, sizeof(QSGClipNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGBasicGeometryNode, QSGClipNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-macos-6.6.2.jar: sources/QtJambiQuick/QSGClipNode_shell.cpp <==
#include "QSGClipNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGClipNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGClipNode")
    QSGClipNode *_ptr = reinterpret_cast<QSGClipNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGClipNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGClipNode_shell) ); }

jmethodID QSGClipNode_shell::__shell_javaMethod(int pos) const { return QSGClipNode_shell::__shell()->javaMethod(typeid(QSGClipNode), pos); }

// emitting (writeShellConstructor)
QSGClipNode_shell::QSGClipNode_shell()
    : QSGClipNode()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGClipNode::QSGClipNode_shell()", QSGClipNode_shell::__shell())
    QSGClipNode_shell::__shell()->constructed(typeid(QSGClipNode));
}

// emitting (writeShellDestructor)
QSGClipNode_shell::~QSGClipNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGClipNode::~QSGClipNode()", QSGClipNode_shell::__shell())
    QSGClipNode_shell::__shell()->destructed(typeid(QSGClipNode));
}

void QSGClipNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGClipNode_shell*>(ptr)->QSGClipNode_shell::__shell()->tryDeleteShell(typeid(QSGClipNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGClipNode_shell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSGClipNode::", QSGClipNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGClipNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGClipNode_shell::__shell()->warnForMethod("QSGClipNode::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGClipNode::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGNode::isSubtreeBlocked();
        }
    }else{
        return QSGNode::isSubtreeBlocked();
    }
}

void QSGClipNode_shell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSGClipNode::", QSGClipNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGClipNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QSGClipNode_shell::__shell()->warnForMethod("QSGClipNode::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGClipNode::");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QSGClipNode()
void __qt_construct_QSGClipNode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGClipNode()")
    Q_UNUSED(__java_arguments)
    QSGClipNode *__qt_this = new(__qtjambi_ptr) QSGClipNode_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QSGClipNode::QSGClipNode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_initialize_1native__Lio_qt_quick_QSGClipNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGClipNode::QSGClipNode()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGClipNode, sizeof(QSGClipNode_shell), typeid(QSGClipNode), true, &deleter_QSGClipNode, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGClipNode_shell
void __qt_destruct_QSGClipNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGClipNode")
    reinterpret_cast<QSGClipNode_shell*>(ptr)->~QSGClipNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGClipNode::clipRect()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_clipRect_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGClipNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGClipNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGClipNode::clipRect()const", __qt_this)
        QRectF __qt_return_value = __qt_this->clipRect();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGClipNode::isRectangular()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_isRectangular_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QSGClipNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGClipNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGClipNode::isRectangular()const", __qt_this)
        __java_return_value = __qt_this->isRectangular();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGClipNode::setClipRect(QRectF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_setClipRect_1native_1cref_1QRectF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGClipNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGClipNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGClipNode::setClipRect(QRectF)", __qt_this)
        const QRectF& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QRectF>(arg__1);
        __qt_this->setClipRect(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGClipNode::setIsRectangular(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGClipNode_setIsRectangular_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean rectHint0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGClipNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGClipNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGClipNode::setIsRectangular(bool)", __qt_this)
        __qt_this->setIsRectangular(static_cast<bool>(rectHint0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSGClipNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGClipNode>("QSGClipNode", "io/qt/quick/QSGClipNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, &__qt_destruct_QSGClipNode, {
        ConstructorInfo(&__qt_construct_QSGClipNode, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGClipNode);
    registerSizeOfShell(typeId, sizeof(QSGClipNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGBasicGeometryNode, QSGClipNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
